import React, { Suspense, useEffect } from "react";
import { Routes, Route, useNavigate } from "react-router-dom";

import { URLs } from "./__data__/urls";
import { ProfilePage, AboutPage } from "./pages";
import { ErrorBoundary } from "./components/error-boundary";

const PageWrapper = ({ children }) => (
  <ErrorBoundary>
    <Suspense fallback={<div>Loading...</div>}>{children}</Suspense>
  </ErrorBoundary>
);

const Redirect = ({ to }: { to: string }) => {
  const navigate = useNavigate();

  useEffect(() => {
    navigate(to)
  }, [navigate])

  return null
}

export const Dashboard = () => {
  return (
    <Routes>
      <Route
        path={URLs.baseUrl}
        element={(
          <Redirect to={URLs.about.getUrl()} />
        )}
      />
      <Route
        path={URLs.about.url}
        element={
          <PageWrapper>
            <AboutPage />
          </PageWrapper>
        }
      />
      {URLs.profile.isOn && (
        <Route
          path={URLs.profile.url}
          element={
            <PageWrapper>
              <ProfilePage />
            </PageWrapper>
          }
        />
      )}

      <Route path="*" element={<div>Not found</div>} />
    </Routes>
  );
};
